@@ -110,7 +110,11 @@ docsToExp env hr scope docs = do
     case exps of
         [] -> [|return ()|]
         [x] -> return x
-        _ -> return $ DoE $ map NoBindS exps
+        _ -> return $ DoE
+#if MIN_VERSION_template_haskell(2,17,0)
+                Nothing
+#endif
+                $ map NoBindS exps
 
 unIdent :: Ident -> String
 unIdent (Ident s) = s
@@ -135,7 +139,7 @@ bindingPattern (BindList is) = do
     return (ListP patterns, concat scopes)
 bindingPattern (BindConstr con is) = do
     (patterns, scopes) <- fmap unzip $ mapM bindingPattern is
-    return (ConP (mkConName con) patterns, concat scopes)
+    return (conP (mkConName con) patterns, concat scopes)
 bindingPattern (BindRecord con fields wild) = do
     let f (Ident field,b) =
            do (p,s) <- bindingPattern b
@@ -153,6 +157,13 @@ conToStr :: DataConstr -> String
 conToStr (DCUnqualified (Ident x)) = x
 conToStr (DCQualified (Module xs) (Ident x)) = intercalate "." $ xs ++ [x]
 
+conP :: Name -> [Pat] -> Pat
+#if MIN_VERSION_template_haskell(2,18,0)
+conP name = ConP name []
+#else
+conP = ConP
+#endif
+
 -- Wildcards bind all of the unbound fields to variables whose name
 -- matches the field name.
 --
